# README
The file `spe_chembl.txt` was taken from the `SmilesPE`
[repository](https://github.com/XinhaoLi74/SmilesPE). While `SmilesPE` is a pypi
package and a dependency of `pytoda`, the `spe_chembl.txt` is not part of the
package.
Since the entire repository is licensed under Apache 2.0, we integrated this file
natively into `pytoda`, but give full credits to the `SmilesPE` developers.

If you use this part of `pytoda`, consider citing their paper:

```bib
@article{li2020smiles,
  title={SMILES Pair Encoding: A Data-Driven Substructure Tokenization Algorithm for Deep Learning},
  author={Li, Xinhao and Fourches, Denis},
  year={2020},
  publisher={ChemRxiv}
}
```